==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/thyra/src/support/operator_vector/adapter_support/Thyra_LinearOpScalarProd_def.hpp <==
// @HEADER
// ***********************************************************************
// 
//    Thyra: Interfaces and Support for Abstract Numerical Algorithms
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef THYRA_LINEAR_OP_SCALAR_PROD_DEF_HPP
#define THYRA_LINEAR_OP_SCALAR_PROD_DEF_HPP

#include "Thyra_LinearOpScalarProd_decl.hpp"
#include "Thyra_ScalarProdBase.hpp"
#include "Thyra_MultiVectorStdOps.hpp"
#include "Thyra_EuclideanLinearOpBase.hpp"


namespace Thyra {


// Constructors, initializers, accessors


template<class Scalar>
LinearOpScalarProd<Scalar>::LinearOpScalarProd()
{}


template<class Scalar>
LinearOpScalarProd<Scalar>::LinearOpScalarProd(
  const Teuchos::RCP<const LinearOpBase<Scalar> > &op_in )
{
  this->initialize(op_in);
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::initialize(
  const Teuchos::RCP<const LinearOpBase<Scalar> > &op_in
  )
{
#ifdef TEUCHOS_DEBUG
  TEST_FOR_EXCEPT(is_null(op_in));
#endif
  op_ = op_in;
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::uninitialize(
  const Ptr<RCP<const LinearOpBase<Scalar> > > &op_out
  )
{
  if (!is_null(op_out)) *op_out = op_;
  op_ = Teuchos::null;
}


// Overridden from ScalarProdBase


template<class Scalar>
bool LinearOpScalarProd<Scalar>::isEuclideanImpl() const
{
  return false;
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::scalarProdsImpl(
  const MultiVectorBase<Scalar>& X, const MultiVectorBase<Scalar>& Y,
  const ArrayView<Scalar> &scalarProds_out
  ) const
{
  Teuchos::RCP<MultiVectorBase<Scalar> >
    T = createMembers(Y.range() ,Y.domain()->dim());
  Thyra::apply(*op_, NOTRANS,Y, &*T);
  dots(X, *T, scalarProds_out);
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::euclideanApplyImpl(
  const EuclideanLinearOpBase<Scalar> &M,
  const EOpTransp M_trans,
  const MultiVectorBase<Scalar> &X,
  const Ptr<MultiVectorBase<Scalar> > &Y,
  const Scalar alpha,
  const Scalar beta
  ) const
{
  Teuchos::RCP<MultiVectorBase<Scalar> >
    T = createMembers(X.range(),X.domain()->dim());
  Thyra::apply(*op_, NOTRANS, X, &*T);
  Thyra::euclideanApply(M, M_trans, *T, &*Y, alpha, beta);
}


} // end namespace Thyra


#endif  // THYRA_LINEAR_OP_SCALAR_PROD_DEF_HPP

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/thyra/src/support/operator_vector/adapter_support/Thyra_LinearOpScalarProd_def.hpp <==
// @HEADER
// ***********************************************************************
// 
//    Thyra: Interfaces and Support for Abstract Numerical Algorithms
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef THYRA_LINEAR_OP_SCALAR_PROD_DEF_HPP
#define THYRA_LINEAR_OP_SCALAR_PROD_DEF_HPP

#include "Thyra_LinearOpScalarProd_decl.hpp"
#include "Thyra_ScalarProdBase.hpp"
#include "Thyra_LinearOpBase.hpp"
#include "Thyra_MultiVectorStdOps.hpp"
#include "Thyra_MultiVectorBase.hpp"
#include "Thyra_VectorSpaceBase.hpp"


namespace Thyra {


// Constructors, initializers, accessors


template<class Scalar>
LinearOpScalarProd<Scalar>::LinearOpScalarProd()
{}


template<class Scalar>
LinearOpScalarProd<Scalar>::LinearOpScalarProd(
  const Teuchos::RCP<const LinearOpBase<Scalar> > &op_in )
{
  this->initialize(op_in);
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::initialize(
  const Teuchos::RCP<const LinearOpBase<Scalar> > &op_in
  )
{
#ifdef TEUCHOS_DEBUG
  TEST_FOR_EXCEPT(is_null(op_in));
#endif
  op_ = op_in;
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::uninitialize(
  const Ptr<RCP<const LinearOpBase<Scalar> > > &op_out
  )
{
  if (!is_null(op_out)) *op_out = op_;
  op_ = Teuchos::null;
}


// Overridden from ScalarProdBase


template<class Scalar>
bool LinearOpScalarProd<Scalar>::isEuclideanImpl() const
{
  return false;
}


template<class Scalar>
void LinearOpScalarProd<Scalar>::scalarProdsImpl(
  const MultiVectorBase<Scalar>& X, const MultiVectorBase<Scalar>& Y,
  const ArrayView<Scalar> &scalarProds_out
  ) const
{
  Teuchos::RCP<MultiVectorBase<Scalar> >
    T = createMembers(Y.range() ,Y.domain()->dim());
  Thyra::apply(*op_, NOTRANS,Y, T.ptr());
  dots(X, *T, scalarProds_out);
}


template<class Scalar>
RCP<const LinearOpBase<Scalar> >
LinearOpScalarProd<Scalar>::getLinearOpImpl() const
{
  return op_;
}


} // end namespace Thyra


#endif  // THYRA_LINEAR_OP_SCALAR_PROD_DEF_HPP
